Struct Channel
pub struct Channel<T> { /* private fields */ }Available on crate feature
wayland and Linux only.Expand description
The receiving end of the channel
This is the event source to be inserted into your EventLoop.
Implementations
impl<T> Channel<T>
impl<T> Channel<T>
pub fn recv(&self) -> Result<T, RecvError>
pub fn recv(&self) -> Result<T, RecvError>
Proxy for mpsc::Receiver::recv to manually poll events.
Note: Normally you would want to use the Channel by inserting
it into an event loop instead. Use this for example to immediately
dispatch pending events after creation.
pub fn try_recv(&self) -> Result<T, TryRecvError>
pub fn try_recv(&self) -> Result<T, TryRecvError>
Proxy for mpsc::Receiver::try_recv to manually poll events.
Note: Normally you would want to use the Channel by inserting
it into an event loop instead. Use this for example to immediately
dispatch pending events after creation.