Struct SyncSender
pub struct SyncSender<T> { /* private fields */ }wayland_platform only.Expand description
The sender end of a synchronous channel
It can be cloned and sent accross threads (if T is).
Implementations
impl<T> SyncSender<T>
impl<T> SyncSender<T>
pub fn send(&self, t: T) -> Result<(), SendError<T>>
pub fn send(&self, t: T) -> Result<(), SendError<T>>
Send a message to the synchronous channel
This will wake the event loop and deliver an Event::Msg to
it containing the provided value. If the channel is full, this
function will block until the event loop empties it and it can
deliver the message.
Due to the blocking behavior, this method should not be used on the same thread as the one running the event loop, as it could cause deadlocks.
pub fn try_send(&self, t: T) -> Result<(), TrySendError<T>>
pub fn try_send(&self, t: T) -> Result<(), TrySendError<T>>
Send a message to the synchronous channel
This will wake the event loop and deliver an Event::Msg to
it containing the provided value. If the channel is full, this
function will return an error, but the event loop will still be
signaled for readiness.